@@ -44,7 +44,7 @@ class PubSub:
         while await channel.wait_message():
             self.logger.debug('New {}.'.format(datakind))
             try:
-                message = await channel.get()
+                _, message = await channel.get(encoding='utf-8')
                 asyncio.create_task(callback(await parser.decode_message(message, self.custom_data_decoder)))
             except:
                 self.logger.error(traceback.format_exc())
