@@ -64,6 +64,8 @@ class Service:
                     running = False
             await self._close()
         except:
+            import traceback
+            traceback.print_exc()
             await self._close()
 
     async def _close(self) -> None:
