@@ -1,39 +1,8 @@
 #!/usr/bin/env python3
 
 
-class AttId:
-    att = 'att'
-    centerxy = 'centerxy'
-    datapointeid = 'datapointeid'
-    datapointseids = 'datapointseids'
-    datatypeeid = 'datatypeeid'
-    day = 'day'
-    eid = 'eid'
-    ffspeed = 'ffspeed'
-    fow = 'fow'
-    frc = 'frc'
-    fromno = 'fromno'
-    geom = 'geom'
-    geomxy = 'geomxy'
-    id = 'id'
-    length = 'length'
-    mainroad = 'mainroad'
-    maxspeed = 'maxspeed'
-    name = 'name'
-    nlanes = 'nlanes'
-    no = 'no'
-    roadeid = 'roadeid'
-    roads = 'roads'
-    tono = 'tono'
-    sample = 'sample'
-    sampletime = 'sampletime'
-    validfrom = 'validfrom'
-    validto = 'validto'
-    webatt = 'webatt'
-    zoneeid = 'zoneeid'
-
-
 class DbColumn:
+    att = 'att'
     datapoint = 'data_point'
     datatype = 'data_type'
     dataquality = 'data_quality'
@@ -41,6 +10,7 @@ class DbColumn:
     eid = 'eid'
     fromtraveltime = 'from_travel_time'
     fromzonepoint = 'from_zone_point'
+    id = 'id'
     imputedindicator = 'imputed_indicator'
     indicator = 'indicator'
     networkdataquality = 'network_data_quality'
@@ -50,6 +20,8 @@ class DbColumn:
     totraveltime = 'to_travel_time'
     tozonepoint = 'to_zone_point'
     validfrom = 'valid_from'
+    validto = 'valid_to'
+    webatt = 'web_att'
 
 
 class DbTable:
@@ -92,6 +64,25 @@ class MessageData:
     nan = -1
 
 
+class AttId(DbColumn):
+    centerxy = 'centerxy'
+    datapointseids = 'datapoints'
+    ffspeed = 'ffspeed'
+    fow = 'fow'
+    frc = 'frc'
+    fromno = 'fromno'
+    geomxy = 'geomxy'
+    length = 'length'
+    mainroad = 'mainroad'
+    maxspeed = 'maxspeed'
+    name = 'name'
+    nlanes = 'nlanes'
+    no = 'no'
+    roads = 'roads'
+    tono = 'tono'
+    zone = 'zone'
+
+
 class MessageFormat:
     json = 'json'
     pandas = 'pandas'
