@@ -5,9 +5,8 @@ from typing import Generator, Iterable, List, Tuple
 
 import shapely.geometry
 from shapely.geometry.base import BaseGeometry
-import shapely.geos
 import shapely.ops
-import shapely.wkb
+import shapely.wkt
 
 LONLAT_CENTER = (5.74626, 45.17475)
 LONLAT_EXTEND = ((5.60268, 45.0821), (5.88934, 45.2674))
@@ -131,14 +130,12 @@ def _get_range(i: int, radius: int) -> List[int]:
     return sorted(range(i - radius, i + radius + 1), key=lambda x: abs(x - i))
 
 
-def encode_geometry(geometry: BaseGeometry) -> bytes:
+def encode_geometry(geometry: BaseGeometry) -> str:
     if not hasattr(geometry, '__geo_interface__'):
         raise TypeError('{g} does not conform to '
                         'the geo interface'.format(g=geometry))
-    shape = shapely.geometry.asShape(geometry)
-    shapely.geos.lgeos.GEOSSetSRID(shape._geom, SRID)
-    return shapely.wkb.dumps(shape, include_srid=True)
+    return '{};{}'.format('SRID={}'.format(SRID), shapely.wkt.dumps(geometry))
 
 
-def decode_geometry(wkb: bytes) -> BaseGeometry:
-    return shapely.wkb.loads(wkb)
+def decode_geometry(wkt: str) -> BaseGeometry:
+    return shapely.wkt.loads(wkt.split(';')[-1])
