@@ -71,7 +71,7 @@ def object_hook(obj: dict, custom_data_decoder: Callable = None) -> dict:
         elif key == AttId.geom:
             val = decode_geometry(obj[key])
         if val is not None:
-            key[obj] = val
+            obj[key] = val
     return obj
 
 
